Index: Source/core/html/FormAssociatedElement.h |
diff --git a/Source/core/html/FormAssociatedElement.h b/Source/core/html/FormAssociatedElement.h |
index 3bfd4cd25e1ce0807e877838b365a804b06a0813..a9dc6437b9d41d05f4c2bd7453f2e1b8779e045d 100644 |
--- a/Source/core/html/FormAssociatedElement.h |
+++ b/Source/core/html/FormAssociatedElement.h |
@@ -85,12 +85,11 @@ public: |
void formAttributeTargetChanged(); |
// We can't pass FormAssociatedElement pointer into Visitor::visit function |
// directly because it does not coincide with the actual start of the object |
// and visitor has to access object header. Thus we need a helper method |
- // that would correctly adjust the pointer before passing it into the |
- // visitor. |
- virtual void visitWith(Visitor*) const = 0; |
+ // that will adjust the pointer before passing it into the visitor. |
+ virtual void adjustAndMark(Visitor*) const = 0; |
void trace(Visitor*); |
HTMLElement* asHTMLElement(); |
@@ -125,7 +124,7 @@ private: |
template<> class TraceTrait<FormAssociatedElement> { |
public: |
- static void visit(Visitor* visitor, const FormAssociatedElement* self) { self->visitWith(visitor); } |
+ static void mark(Visitor* visitor, const FormAssociatedElement* self) { self->adjustAndMark(visitor); } |
static intptr_t getTypeMarker() { return 0; } |
static void checkTypeMarker(Visitor*, const FormAssociatedElement*) { } |
static void trace(Visitor* visitor, void* self) { static_cast<FormAssociatedElement*>(self)->trace(visitor); } |
@@ -85,12 +85,11 @@ public: |
void formAttributeTargetChanged(); |
- // We can't pass FormAssociatedElement pointer into Visitor::visit function |
+ // We can't pass FormAssociatedElement pointer into Visitor::mark function |
// directly because it does not coincide with the actual start of the object |
// and visitor has to access object header. Thus we need a helper method |